@@ -5,10 +5,15 @@ bd_ML = function(brts, initparsopt = c(0.1,0.05), idparsopt = 1:length(initparso
 # - min(brts) = most recent branching time
 # - initpars[1] = la0 = (initial) speciation rate
 # - initpars[2] = mu0 = (initial) extinction rate
-# - initpars[3] = la1 = exponential decline parameter of speciation rate
+# - initpars[3] = la1 = exponential decline parameter of speciation rate or K in diversity-dependence-like models
 # - initpars[4] = mu1 = exponential decline parameter of extinction rate
 # - res = resolution of the method; res should be larger than the total number of species
 # - missnumspec = number of missing species    
+# - tdmodel = type of time-dependent model
+#  . tdmodel == 0: no time-dependence
+#  . tdmodel == 1: exponential decline in speciation or extinction rate
+#  . tdmodel == 2: stepwise decline following diversity-dependence when extinction = 0
+#  . tdmodel == 3: decline in speciation rate following deterministic logistic equation for ddmodel = 1
 # - cond = conditioning
 #  . cond == 0 : no conditioning
 #  . cond == 1 : conditioning on non-extinction of the phylogeny
@@ -33,7 +38,9 @@ if((sum(idpars == (1:4)) != 4) || (length(initparsopt) != length(idparsopt)) ||
    cat("The parameters to be optimized and/or fixed are incoherent.\n")
    out2 = data.frame(lambda0 = -1,mu0 = -1,lambda1 = -1, mu1 = -1, loglik = -1, df = -1, conv = -1)
 } else {
-namepars = c("lambda0","mu0","lambda1","mu1")
+namepars1 = c("lambda0","mu0","lambda1","mu1")
+namepars2 = c("lambda0","mu0","K","-")
+if(tdmodel == 2 | tdmodel == 3) { namepars = namepars2 } else  { namepars = namepars1 }
 if(length(namepars[idparsopt]) == 0) { optstr = "nothing" } else { optstr = namepars[idparsopt] }
 cat("You are optimizing",optstr,"\n")
 if(length(namepars[idparsfix]) == 0) { fixstr = "nothing" } else { fixstr = namepars[idparsfix] }
@@ -41,9 +48,10 @@ cat("You are fixing",fixstr,"\n")
 cat("Optimizing the likelihood - this may take a while.","\n")
 flush.console()
 trparsopt = initparsopt/(1 + initparsopt)
+trparsopt[which(initparsopt == Inf)] = 1
 trparsfix = parsfix/(1 + parsfix)
 trparsfix[which(parsfix == Inf)] = 1
-pars2 = c(tdmodel,cond,btorph,0,soc,tol,maxiter)
+pars2 = c(tdmodel,cond,btorph,0,soc,1000,tol,maxiter)
 initloglik = bd_loglik_choosepar(trparsopt = trparsopt,trparsfix = trparsfix,idparsopt = idparsopt,idparsfix = idparsfix,pars2 = pars2,brts = brts,missnumspec = missnumspec)
 cat("The loglikelihood for the inital parameter values is",initloglik,"\n")
 if(initloglik == -Inf)
